package com.taobao.weex.utils;

import android.content.Intent;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.net.Uri;
import android.text.TextUtils;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.font.FontAdapter;
import java.io.File;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class TypefaceUtil {
    public static final String ACTION_TYPE_FACE_AVAILABLE = "type_face_available";
    public static final String FONT_CACHE_DIR_NAME = "font-family";
    private static final String TAG = "TypefaceUtil";
    private static final Map<String, FontDO> sCacheMap = new HashMap();

    public static void putFontDO(FontDO fontDO) {
        if (fontDO == null || TextUtils.isEmpty(fontDO.getFontFamilyName())) {
            return;
        }
        sCacheMap.put(fontDO.getFontFamilyName(), fontDO);
    }

    public static void registerNativeFont(Map<String, Typeface> fonts) {
        if (fonts == null || fonts.size() <= 0) {
            return;
        }
        for (Map.Entry<String, Typeface> entry : fonts.entrySet()) {
            putFontDO(new FontDO(entry.getKey(), entry.getValue()));
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d(TAG, "register new typeface: " + entry.getKey());
            }
        }
    }

    public static FontDO getFontDO(String fontFamilyName) {
        return sCacheMap.get(fontFamilyName);
    }

    public static void removeFontDO(String fontFamilyName) {
        sCacheMap.remove(fontFamilyName);
    }

    public static void applyFontStyle(Paint paint, int style, int weight, String family) {
        Typeface typeface = paint.getTypeface();
        int style2 = typeface == null ? 0 : typeface.getStyle();
        int i = 1;
        if (weight != 1 && ((style2 & 1) == 0 || weight != -1)) {
            i = 0;
        }
        if (style == 2 || ((style2 & 2) != 0 && style == -1)) {
            i |= 2;
        }
        if (family != null) {
            typeface = getOrCreateTypeface(family, i);
        }
        if (typeface != null) {
            paint.setTypeface(Typeface.create(typeface, i));
        } else {
            paint.setTypeface(Typeface.defaultFromStyle(i));
        }
        if (style >= 0) {
            paint.setTextSkewX(((style & ((paint.getTypeface() != null ? paint.getTypeface().getStyle() : 0) ^ (-1))) & 2) != 0 ? -0.2f : 0.0f);
        }
    }

    public static Typeface getOrCreateTypeface(String family, int style) {
        FontDO fontDO = sCacheMap.get(family);
        if (fontDO != null && fontDO.getTypeface() != null) {
            return fontDO.getTypeface();
        }
        return Typeface.create(family, style);
    }

    private static void loadFromAsset(FontDO fontDo, String path) {
        try {
            Typeface createFromAsset = Typeface.createFromAsset(WXEnvironment.getApplication().getAssets(), path);
            if (createFromAsset != null) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d(TAG, "load asset file success");
                }
                fontDo.setState(2);
                fontDo.setTypeface(createFromAsset);
                return;
            }
            WXLogUtils.e(TAG, "Font asset file not found " + fontDo.getUrl());
        } catch (Exception e) {
            WXLogUtils.e(TAG, e.toString());
        }
    }

    public static void loadTypeface(final FontDO fontDo, boolean notify) {
        if (fontDo == null || fontDo.getTypeface() != null || (fontDo.getState() != 3 && fontDo.getState() != 0)) {
            if (notify) {
                notifyFontAvailable(false, fontDo);
                return;
            }
            return;
        }
        fontDo.setState(1);
        if (fontDo.getType() == 3) {
            loadFromAsset(fontDo, Uri.parse(fontDo.getUrl()).getPath().substring(1));
        } else if (fontDo.getType() == 1) {
            String url = fontDo.getUrl();
            String fontFamilyName = fontDo.getFontFamilyName();
            String md5 = WXFileUtils.md5(url);
            File file = new File(getFontCacheDir());
            if (!file.exists()) {
                file.mkdirs();
            }
            String str = file.getAbsolutePath() + File.separator + md5;
            if (loadLocalFontFile(str, fontFamilyName, false)) {
                return;
            }
            downloadFontByNetwork(url, str, fontFamilyName);
        } else if ((fontDo.getType() == 2 || fontDo.getType() == 5) && !loadLocalFontFile(fontDo.getUrl(), fontDo.getFontFamilyName(), false)) {
            fontDo.setState(3);
        }
    }

    private static void downloadFontByNetwork(final String url, final String fullPath, final String fontFamily) {
        IWXHttpAdapter iWXHttpAdapter = WXSDKManager.getInstance().getIWXHttpAdapter();
        if (iWXHttpAdapter == null) {
            WXLogUtils.e(TAG, "downloadFontByNetwork() IWXHttpAdapter == null");
            return;
        }
        WXRequest wXRequest = new WXRequest();
        wXRequest.url = url;
        wXRequest.method = "GET";
        iWXHttpAdapter.sendRequest(wXRequest, new IWXHttpAdapter.OnHttpListener() { // from class: com.taobao.weex.utils.TypefaceUtil.1
            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHeadersReceived(int statusCode, Map<String, List<String>> headers) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpResponseProgress(int loadedLength) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpUploadProgress(int uploadProgress) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpStart() {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d(TypefaceUtil.TAG, "downloadFontByNetwork begin url:" + url);
                }
            }

            /* JADX WARN: Removed duplicated region for block: B:16:0x0043  */
            /* JADX WARN: Removed duplicated region for block: B:17:0x004d  */
            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            /*
                Code decompiled incorrectly, please refer to instructions dump.
            */
            public void onHttpFinish(WXResponse response) {
                int parseInt;
                FontDO fontDO;
                boolean z = false;
                if (!TextUtils.isEmpty(response.statusCode)) {
                    try {
                        parseInt = Integer.parseInt(response.statusCode);
                    } catch (NumberFormatException unused) {
                        WXLogUtils.e(TypefaceUtil.TAG, "IWXHttpAdapter onHttpFinish statusCode:" + response.statusCode);
                    }
                    if (parseInt >= 200 && parseInt <= 299 && response.originalData != null) {
                        z = WXFileUtils.saveFile(fullPath, response.originalData, WXEnvironment.getApplication());
                        if (!z) {
                            z = TypefaceUtil.loadLocalFontFile(fullPath, fontFamily, true);
                        } else if (WXEnvironment.isApkDebugable()) {
                            WXLogUtils.d(TypefaceUtil.TAG, "downloadFontByNetwork() onHttpFinish success, but save file failed.");
                        }
                    }
                    if (!z || (fontDO = (FontDO) TypefaceUtil.sCacheMap.get(fontFamily)) == null) {
                    }
                    fontDO.setState(3);
                    return;
                }
                parseInt = 0;
                if (parseInt >= 200) {
                    z = WXFileUtils.saveFile(fullPath, response.originalData, WXEnvironment.getApplication());
                    if (!z) {
                    }
                }
                if (z) {
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean loadLocalFontFile(final String path, final String fontFamily, boolean hasNetworkDowload) {
        if (!TextUtils.isEmpty(path) && !TextUtils.isEmpty(fontFamily)) {
            try {
                if (!new File(path).exists()) {
                    return false;
                }
                Typeface createFromFile = Typeface.createFromFile(path);
                if (createFromFile != null) {
                    final FontDO fontDO = sCacheMap.get(fontFamily);
                    if (fontDO != null) {
                        fontDO.setState(2);
                        fontDO.setTypeface(createFromFile);
                        fontDO.setFilePath(path);
                        if (WXEnvironment.isApkDebugable()) {
                            WXLogUtils.d(TAG, "load local font file success");
                        }
                        if (hasNetworkDowload) {
                            WXSDKManager.getInstance().getWXRenderManager().postOnUiThread(new Runnable() { // from class: com.taobao.weex.utils.TypefaceUtil.2
                                @Override // java.lang.Runnable
                                public void run() {
                                    TypefaceUtil.notifyFontAvailable(true, FontDO.this);
                                }
                            }, 100L);
                        } else {
                            notifyFontAvailable(true, fontDO);
                        }
                        return true;
                    }
                } else {
                    WXLogUtils.e(TAG, "load local font file failed, can't create font.");
                }
            } catch (Exception e) {
                WXLogUtils.e(TAG, e.toString());
            }
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void notifyFontAvailable(boolean sendBroadcast, FontDO fontDO) {
        if (sendBroadcast) {
            Intent intent = new Intent(ACTION_TYPE_FACE_AVAILABLE);
            intent.putExtra(Constants.Name.FONT_FAMILY, fontDO.getFontFamilyName());
            intent.putExtra("filePath", fontDO.getFilePath());
            intent.putExtra("fontUrl", fontDO.getUrl());
            LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).sendBroadcast(intent);
        }
        FontAdapter fontAdapter = WXSDKManager.getInstance().getFontAdapter();
        if (fontAdapter != null) {
            fontAdapter.onFontLoad(fontDO.getFontFamilyName(), fontDO.getUrl(), fontDO.getFilePath());
        }
    }

    private static String getFontCacheDir() {
        return WXEnvironment.getApplication().getCacheDir() + "/" + FONT_CACHE_DIR_NAME;
    }
}
